<?php

namespace Drp\ProjectHelpers;

use Collective\Html\HtmlServiceProvider;
use Drp\ProjectHelpers\Form\BootstrapForm;
use Illuminate\Support\ServiceProvider;
use Laracasts\Flash\FlashServiceProvider;

/**
 * Class ProjectHelpersServiceProvider
 * @package Drp\ProjectHelpers
 * @SuppressWarnings(PHPMD.CouplingBetweenObjects)
 */
class ProjectHelpersServiceProvider extends ServiceProvider
{
    /**
     * Boot the service provider.
     *
     * @return void
     */
    public function boot()
    {
        $this->publishes([
            __DIR__.'/config/bootstrap_form_config.php' => config_path('bootstrap_form.php')
        ], 'config');
    }

    /**
     * Register bindings in the container.
     *
     * @return void
     */
    public function register()
    {
        $this->app->register(HtmlServiceProvider::class);
        $this->app->register(FlashServiceProvider::class);

        $this->app->singleton('bootstrap_form', function($app) {
            return new BootstrapForm($app['html'], $app['form'], $app['config']);
        });

        $this->mergeConfigFrom(__DIR__.'/config/bootstrap_form_config.php', 'bootstrap_form');

        require_once __DIR__ . '/macros.php';
        require_once __DIR__ . '/form_helpers.php';
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['bootstrap_form'];
    }
}
